@@ -1,13 +1,17 @@
 """
 Allows the blog to use the sites framework.
 """
+
+from __future__ import absolute_import, unicode_literals
+
 from django.utils.translation import ugettext_lazy as _
 from django.contrib.sites.models import Site
-from django.db.models import ManyToManyField, CharField
-from django.db.models import Q
+from django.db.models import ManyToManyField, Q
+
 
 def register(cls, admin_cls):
-    cls.add_to_class('sites', ManyToManyField(Site, blank=True,
+    cls.add_to_class('sites', ManyToManyField(
+        Site, blank=True,
         help_text=_('The sites where the blogpost should appear.'),
         default=Site.objects.get_current))
 
@@ -17,7 +21,7 @@ def register(cls, admin_cls):
 
     def sites_admin(self, obj):
         available_sites = self.obj.all()
-        return u', '.join(u'%s' % site.name for site in available_sites)
+        return ', '.join('%s' % site.name for site in available_sites)
 
     sites_admin.allow_tags = True
     sites_admin.short_description = _('Sites')
